<?php

namespace Drupal\search_api_coveo;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\RfcLogLevel;

/**
 * This factory looks up the log threshold and returns a logging channel.
 */
class SearchApiCoveoLoggerFactory implements SearchApiCoveoLoggerFactoryInterface {

  /**
   * A memory cache of configured loggers.
   *
   * @var SearchApiCoveoLoggerChannel[]
   */
  protected array $loggers;

  /**
   * Server storage service.
   */
  protected EntityStorageInterface $serverStorage;

  /**
   * Initialize the factory.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->serverStorage = $entityTypeManager->getStorage('search_api_server');
    $this->loggers = [];
  }

  /**
   * {@inheritdoc}
   */
  public function get(string $serverId): SearchApiCoveoLoggerChannel {
    if (isset($this->loggers[$serverId])) {
      return $this->loggers[$serverId];
    }/** @var \Drupal\search_api\Entity\Server $server */
    $server = $this->serverStorage->load($serverId);
    $config = is_null($server) ? [] : $server->getBackendConfig();
    $threshold = $config['log_threshold'] ?? RfcLogLevel::WARNING;
    $this->loggers[$serverId] = new SearchApiCoveoLoggerChannel($threshold);
    return $this->loggers[$serverId];
  }

}
